; ----------------- assembly instructions ---------------------------- 
;
;****************************************************************************
; Reset, Interrupt, & Break Handlers
;****************************************************************************
;               *= $FF00             ; put this in last page of ROM

;--------------Reset handler----------------------------------------------
Reset          SEI                     ; diable interupts
               CLD                     ; clear decimal mode                      
               LDX   #$FF              ;
               TXS                     ; init stack pointer
               LDA   #<Interrupt
               STA   $FFFE
               LDA   #>Interrupt	
               STA   $FFFF
;
; you can patch in a test for keypress here to bypass memory erase.
; It will then test the vectors, and jump to your routine.
;
Zeromem        lda   #$7F              ; top page of RAM
               sta   $01               ; 
               lda   #$00              ; top of page & fill chr
               sta   $00               ;
               ldy   #$00 
Zeromem1       sta   ($00),y           ; loop will fill loc 0 of each page then 
               dec   $00               ; fill from ff->01 of that page
               bne   zeromem1          ; then will drop one page and fill loc 0
               dec   $01               ; doing that until page is back to FF
               bpl   Zeromem1          ;
               sta   $01               ; fix last byte from ff to 00

Clr_regs       lda   #$00              ; Clear registers
               TAY                     ;
               TAX                     ;
               CLC                     ; clear flags
               CLD                     ; clear decimal mode
               CLI                     ; Enable interrupt system
               JMP  MonitorBoot        ; Monitor for cold reset                       

Interrupt      PHA                     ; a
               TXA  	               ; 
               PHA                     ; X
               TSX                     ; get stack pointer
               LDA   $0103,X           ; load INT-P Reg off stack
               AND   #$10              ; mask BRK
               BNE   BrkCmd            ; BRK CMD
               PLA                     ; x
               tax                     ; 		
               pla                     ; a
NMIjump        RTI                     ; Null Interrupt return
BrkCmd         pla                     ; X
               tax                     ;
               pla                     ; A
               jmp   BRKroutine        ; patch in user BRK routine

;
; *** VERSION Notes ***
; 3.5 added the text dump command, 'q'
; 4.0 reorganized structure, added RAM vectors for chrin, scan_in, and chrout
; 4.1 fixed set time routine so 20-23 is correct    
; 4.2 RST, IRQ, NMI, BRK all jmp ind to 02xx page to allow user prog to control
; 4.3 added status register bits to printreg routine
; 4.4 refined set time to reduce unneeded sec's and branches, disp time added CR,
;     and added zeromem to the reset routine, ensuring a reset starts fresh every time!
;     continued to re-organize - moved monitor's brk handler into mon area.
; 4.5 optimized for CHOCHI

;  65C02 Firmware Notes
;
;  NMIjmp      =     $FFFA             
;  RESjmp      =     $FFFC             
;  INTjmp      =     $FFFE             

;               *=    $FFFA
;               .word  NMIjump
;               .word  Reset 
;               .word  Interrupt
;end of file
